==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/oc.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Important",
    "Today" : "Uèi",
    "Week" : "Aquesta setmana",
    "All" : "Tot",
    "Current" : "En aqueste moment",
    "Completed" : "Acabat",
    "Tasks" : "Prètzfaches",
    "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
    "Hidden" : "Amagat",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Can edit" : "Pòt modificar",
    "Edit" : "Modificar",
    "Copy private link" : "Copiar lo ligam privat",
    "Export" : "Exportar",
    "Delete" : "Suprimir",
    "Unshare" : "Partejar pas",
    "Save" : "Enregistrar",
    "An empty name is not allowed." : "Un nom void es pas autorizat.",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaurar",
    "Delete permanently" : "Suprimir definitivament",
    "Untitled task" : "Prètzfach sens nom",
    "Untitled event" : "Eveniment sens títol",
    "Alphabetically" : "Alfabeticament",
    "[Yesterday]" : "[Ièr]",
    "[Today]" : "[Uèi]",
    "[Tomorrow]" : "[Deman]",
    "Cancel" : "Anullar",
    "Close" : "Tampar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n prètzfach acabat","%n prètzfaches acabats"],
    "Tomorrow" : "Deman",
    "New List" : "Novèla lista",
    "All day" : "Tota la jornada",
    "Edit title" : "Modificar lo títol",
    "Details" : "Detalhs",
    "Notes" : "Nòtas",
    "Reminders" : "Rapèls",
    "Repeat" : "Repetir",
    "Canceled" : "Anullat",
    "Task not found!" : "Prètzfach pas trobat !",
    "Set start date" : "Especificar la data de començament",
    "Set due date" : "Especificar la data d'escasença",
    "An error occurred" : "Una error s’es producha"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/oc.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Prètzfaches venents",
    "Important" : "Important",
    "Today" : "Uèi",
    "Week" : "Aquesta setmana",
    "All" : "Tot",
    "Current" : "En aqueste moment",
    "Completed" : "Acabat",
    "Tasks" : "Prètzfaches",
    "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
    "Hidden" : "Amagat",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Can edit" : "Pòt modificar",
    "Edit" : "Modificar",
    "Copy private link" : "Copiar lo ligam privat",
    "Export" : "Exportar",
    "Delete" : "Suprimir",
    "Unshare" : "Partejar pas mai",
    "An empty name is not allowed." : "Un nom void es pas autorizat.",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaurar",
    "Delete permanently" : "Suprimir definitivament",
    "Untitled task" : "Prètzfach sens nom",
    "Untitled event" : "Eveniment sens títol",
    "Alphabetically" : "Alfabeticament",
    "[Yesterday]" : "[Ièr]",
    "[Today]" : "[Uèi]",
    "[Tomorrow]" : "[Deman]",
    "Cancel" : "Anullar",
    "Close" : "Tampar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n prètzfach acabat","%n prètzfaches acabats"],
    "Tomorrow" : "Deman",
    "All day" : "Tota la jornada",
    "Edit title" : "Modificar lo títol",
    "Details" : "Detalhs",
    "Notes" : "Nòtas",
    "Reminders" : "Rapèls",
    "Repeat" : "Repetir",
    "Canceled" : "Anullat",
    "Task not found!" : "Prètzfach pas trobat !",
    "Set start date" : "Especificar la data de començament",
    "Set due date" : "Especificar la data d'escasença",
    "No upcoming tasks" : "Cap de prètzfach venent",
    "upcoming tasks" : "prètzfaches venents",
    "No tasks today" : "Cap de prètzfach uèi",
    "An error occurred" : "Una error s’es producha"
},
"nplurals=2; plural=(n > 1);");
